summaryrefslogtreecommitdiffstats
path: root/ipalib/plugable.py
diff options
context:
space:
mode:
authorJason Gerard DeRose <jderose@redhat.com>2008-08-06 14:22:38 +0000
committerJason Gerard DeRose <jderose@redhat.com>2008-08-06 14:22:38 +0000
commit2081987186a533bd6c953c8d48dfcfd193802e44 (patch)
tree3225e28ce555e76cd784439c4eb6b4172be6bbc3 /ipalib/plugable.py
parente618d99bc7adb47b724aebf67ea85e59c520e10d (diff)
downloadfreeipa-2081987186a533bd6c953c8d48dfcfd193802e44.tar.gz
freeipa-2081987186a533bd6c953c8d48dfcfd193802e44.tar.xz
freeipa-2081987186a533bd6c953c8d48dfcfd193802e44.zip
58: A bit of docstring cleanup in plugable.py
Diffstat (limited to 'ipalib/plugable.py')
-rw-r--r--ipalib/plugable.py7
1 files changed, 3 insertions, 4 deletions
diff --git a/ipalib/plugable.py b/ipalib/plugable.py
index 01adc613..7602bce3 100644
--- a/ipalib/plugable.py
+++ b/ipalib/plugable.py
@@ -18,7 +18,7 @@
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
"""
-Utility classes for registering plugins, base classes for writing plugins.
+Base classes for plug-in architecture and generative API.
"""
import re
@@ -89,8 +89,7 @@ class Plugin(object):
def __repr__(self):
"""
- Returns a valid Python expression that could create this plugin
- instance given the appropriate environment.
+ Returns a fully qualified <module><name> representation of the class.
"""
return '%s.%s' % (
self.__class__.__module__,
@@ -125,7 +124,7 @@ class ReadOnly(object):
class Proxy(ReadOnly):
"""
Used to only export certain attributes into the dynamic API.
Subclasses must list names of attributes to be proxied in the __slots__
class attribute.
@@ -125,7 +124,7 @@ class ReadOnly(object):
class Proxy(ReadOnly):
"""
- Used to only export certain attributes into the dynamic API.
+ Used to only export certain attributes into the generative API.
Subclasses must list names of attributes to be proxied in the __slots__
class attribute.